==> orbitcpp-1.3.5.tar.gz: orbitcpp-1.3.5/orbitcpp/idl-compiler/types/IDLAny.cc <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: f; c-basic-offset: 8 -*- */
/*
 *  ORBit-C++: C++ bindings for ORBit.
 *
 *  Copyright (C) 2000 Andreas Kloeckner
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author:	Andreas Kloeckner <ak@ixion.net>
 *
 *  Purpose:	IDL compiler type representation
 *
 *
 */

#include "IDLAny.h"

#include "IDLTypedef.h"

string
IDLAny::get_cpp_typename () const
{
	return "::CORBA::Any";
}

string
IDLAny::get_c_typename () const
{
	return "CORBA_any*";
}

bool
IDLAny::is_fixed () const
{
	return false;
}

void
IDLAny::typedef_decl_write (ostream          &ostr,
			    Indent           &indent,
			    IDLCompilerState &state,
			    const IDLTypedef &target,
			    const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"

}

string
IDLAny::stub_decl_arg_get (const string     &cpp_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	std::string ret;
	
	switch (direction)
	{
	case IDL_PARAM_IN:
		ret = "const " + get_cpp_typename () + "& " + cpp_id;
		break;
	case IDL_PARAM_OUT:
		ret = get_cpp_typename () + "_out " + cpp_id;
		break;
	case IDL_PARAM_INOUT:
		ret = get_cpp_typename () + "& " + cpp_id;
		break;
	}
	
	return ret;
}

void
IDLAny::stub_impl_arg_pre (ostream          &ostr,
			   Indent           &indent,
			   const string     &cpp_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	std::string cobj_call;
	
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
		cobj_call = "._orbitcpp_cobj()";
		break;
	case IDL_PARAM_OUT:
		cobj_call = "->_orbitcpp_cobj()";
		break;
	}
	
	ostr << indent << get_c_typename () << " c_" << cpp_id
	     << " = " << cpp_id << cobj_call << ";"
	     << endl;
}

string
IDLAny::stub_impl_arg_call (const string     &cpp_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
		return "c_" + cpp_id;
		break;
	case IDL_PARAM_OUT:
		return "&c_" + cpp_id;
		break;
	}
}
  
void
IDLAny::stub_impl_arg_post (ostream          &ostr,
			    Indent           &indent,
			    const string     &cpp_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}




string
IDLAny::stub_decl_ret_get (const IDLTypedef *active_typedef) const
{
	return get_cpp_typename () + "*";
}
  
void
IDLAny::stub_impl_ret_pre (ostream &ostr,
			   Indent  &indent,
			   const IDLTypedef *active_typedef) const
{
	ostr << indent << get_c_typename () << " c_retval = 0;" << endl;  
}

void
IDLAny::stub_impl_ret_call (ostream          &ostr,
			    Indent           &indent,
			    const string     &c_call_expression,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << "c_retval = " << c_call_expression << ";"
	     << endl;
}

void
IDLAny::stub_impl_ret_post (ostream          &ostr,
			    Indent           &indent,
			    const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}
  



string
IDLAny::skel_decl_arg_get (const string     &c_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	//This should match the C skel generated by regular orbit-idl-2.
	
	std::string ret;

	switch (direction)
	{
	case IDL_PARAM_IN:
		ret = "const " + get_c_typename () + " " + c_id;
		break;
	case IDL_PARAM_INOUT:
		ret = get_c_typename () + " " + c_id;
		break;
	case IDL_PARAM_OUT:
		ret = get_c_typename () + "* " + c_id;
		break;
	}
	
	return ret;
}

void
IDLAny::skel_impl_arg_pre (ostream          &ostr,
			   Indent           &indent,
			   const string     &c_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	string cpp_id = "_cpp_" + c_id;
	string cpp_type = get_cpp_typename ();
	
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:   
		ostr << indent << cpp_type << " " << cpp_id << " = "
		     << "::CORBA::Any::_orbitcpp_wrap (" << c_id << ");"
		     << endl;
		break;
	case IDL_PARAM_OUT:
		ostr << indent << cpp_type << "_var " << cpp_id << ";" << endl;
		break;
	}    
}

string
IDLAny::skel_impl_arg_call (const string     &c_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
	case IDL_PARAM_OUT:
		return "_cpp_" + c_id;
		break;
		//case IDL_PARAM_OUT:
		//  return get_cpp_typename () + "_out(_cpp_" + c_id + ")";
		//  break;
	}    
}

void
IDLAny::skel_impl_arg_post (ostream          &ostr,
			    Indent           &indent,
			    const string     &c_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	string cpp_id = "_cpp_" + c_id;
	
	switch (direction)
	{
	case IDL_PARAM_IN:
		// Do nothing
		break;
	case IDL_PARAM_INOUT:
		ostr << indent << "CORBA_any__copy( " << c_id << ", " << cpp_id
		     << "._orbitcpp_cobj() );" << endl;
		break;
	case IDL_PARAM_OUT:
		ostr << indent << "CORBA_any__copy( *" << c_id << ", " << cpp_id
		     << "->_orbitcpp_cobj() );" << endl;
		break;
	}
}




string
IDLAny::skel_decl_ret_get (const IDLTypedef *active_typedef) const
{
	return get_c_typename ();
}

void
IDLAny::skel_impl_ret_pre (ostream          &ostr,
			   Indent           &indent,
			   const IDLTypedef *active_typedef) const
{
	ostr << indent << get_cpp_typename () << "* _cpp_ret = 0;"
	     << endl;
}

void
IDLAny::skel_impl_ret_call (ostream          &ostr,
			    Indent           &indent,
			    const string     &cpp_call_expression,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << "_cpp_ret = " << cpp_call_expression << ";"
	     << endl;
}

void
IDLAny::skel_impl_ret_post (ostream          &ostr,
			    Indent           &indent,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << get_c_typename () << " c_ret;" << endl;
	ostr << indent << "CORBA_any__copy (c_ret, _cpp_ret->_orbitcpp_cobj ());" << endl;
	ostr << indent << "delete _cpp_ret;" << endl;
	ostr << indent << "return c_ret;" << endl;
}


string
IDLAny::get_cpp_member_typename (const IDLTypedef *active_typedef) const
{
	return "CORBA::Any";
}

string
IDLAny::get_c_member_typename (const IDLTypedef *active_typedef) const
{
	return "CORBA_any";
}

string
IDLAny::get_seq_typename (unsigned int      length,
			  const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"

	string retval;
	string cpp_type = active_typedef ?
		active_typedef->get_cpp_typename () : get_cpp_typename ();
	
	char *tmp = 0;
	if (length)
		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundBoundedSeq< %s, %d>",
				       cpp_type.c_str (), length);
	else
		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundUnboundedSeq< %s >",
				       cpp_type.c_str ());
	
	retval = tmp;
	g_free (tmp);
	
	return retval;
}

string
IDLAny::member_decl_arg_get (const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
	
	cerr << "Any::member_decl_arg_get" << endl;
	
	return "const CORBA::Any&";
}

void
IDLAny::member_impl_arg_copy (ostream          &ostr,
			      Indent           &indent,
			      const string     &cpp_id,
			      const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
	cerr << "Any::member_impl_arg_copy" << endl;
}

void
IDLAny::member_init_cpp (ostream          &ostr,
			 Indent           &indent,
			 const string     &cpp_id,
			 const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}

void
IDLAny::member_init_c (ostream          &ostr,
		       Indent           &indent,
		       const string     &c_id,
		       const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}

void
IDLAny::member_pack_to_c (ostream          &ostr,
			  Indent           &indent,
			  const string     &cpp_id,
			  const string     &c_id,
			  const IDLTypedef *active_typedef) const
{
#if 0
	ostr << indent << "CORBA_any__copy (" << c_id
	     << ", " << cpp_id << "._orbitcpp_cobj ());" << endl;
#endif
}

void
IDLAny::member_unpack_from_c  (ostream          &ostr,
			       Indent           &indent,
			       const string     &cpp_id,
			       const string     &c_id,
			       const IDLTypedef *active_typedef) const
{
#if 0
	ostr << indent << cpp_id << ".copy ("
	     << "CORBA::Any::_orbitcpp_wrap (" << c_id << "));" << endl;
#endif
}

==> orbitcpp-1.3.7.tar.gz: orbitcpp-1.3.7/orbitcpp/idl-compiler/types/IDLAny.cc <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: f; c-basic-offset: 8 -*- */
/*
 *  ORBit-C++: C++ bindings for ORBit.
 *
 *  Copyright (C) 2000 Andreas Kloeckner
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author:	Andreas Kloeckner <ak@ixion.net>
 *
 *  Purpose:	IDL compiler type representation
 *
 *
 */

#include "IDLAny.h"

#include "IDLTypedef.h"

string
IDLAny::get_cpp_typename () const
{
	return "::CORBA::Any";
}

string
IDLAny::get_c_typename () const
{
	return "CORBA_any*";
}

bool
IDLAny::is_fixed () const
{
	return false;
}

void
IDLAny::typedef_decl_write (ostream          &ostr,
			    Indent           &indent,
			    IDLCompilerState &state,
			    const IDLTypedef &target,
			    const IDLTypedef *active_typedef) const
{
	const string src_id = get_cpp_typename ();
	const string target_id = target.get_cpp_identifier ();
	ostr << indent << "typedef " << src_id << " " << target_id << ";\n";
}

string
IDLAny::stub_decl_arg_get (const string     &cpp_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	std::string ret;
	
	switch (direction)
	{
	case IDL_PARAM_IN:
		ret = "const " + get_cpp_typename () + "& " + cpp_id;
		break;
	case IDL_PARAM_OUT:
		ret = get_cpp_typename () + "_out " + cpp_id;
		break;
	case IDL_PARAM_INOUT:
		ret = get_cpp_typename () + "& " + cpp_id;
		break;
	}
	
	return ret;
}

void
IDLAny::stub_impl_arg_pre (ostream          &ostr,
			   Indent           &indent,
			   const string     &cpp_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
		ostr << indent << get_c_typename () << " c_" << cpp_id
		     << " = " << cpp_id << "._orbitcpp_cobj();\n";
		break;
	case IDL_PARAM_OUT:
		ostr << indent << get_c_typename () << " c_" << cpp_id
		     << " = 0;\n";
		break;
	}
}

string
IDLAny::stub_impl_arg_call (const string     &cpp_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
		return "c_" + cpp_id;
		break;
	case IDL_PARAM_OUT:
		return "&c_" + cpp_id;
		break;
	}
}
  
void
IDLAny::stub_impl_arg_post (ostream          &ostr,
			    Indent           &indent,
			    const string     &cpp_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
		break;
	case IDL_PARAM_OUT:
		ostr << indent << cpp_id << " = new CORBA::Any(CORBA::Any::_orbitcpp_wrap(c_" << cpp_id << "));\n";

		break;
	}
}




string
IDLAny::stub_decl_ret_get (const IDLTypedef *active_typedef) const
{
	return get_cpp_typename () + "*";
}
  
void
IDLAny::stub_impl_ret_pre (ostream &ostr,
			   Indent  &indent,
			   const IDLTypedef *active_typedef) const
{
	ostr << indent << get_c_typename () << " c_retval = 0;" << endl;  
}

void
IDLAny::stub_impl_ret_call (ostream          &ostr,
			    Indent           &indent,
			    const string     &c_call_expression,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << "c_retval = " << c_call_expression << ";"
	     << endl;
}

void
IDLAny::stub_impl_ret_post (ostream          &ostr,
			    Indent           &indent,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << "return new CORBA::Any(CORBA::Any::_orbitcpp_wrap(c_retval));\n";
}
  



string
IDLAny::skel_decl_arg_get (const string     &c_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	//This should match the C skel generated by regular orbit-idl-2.
	
	std::string ret;

	switch (direction)
	{
	case IDL_PARAM_IN:
		ret = "const " + get_c_typename () + " " + c_id;
		break;
	case IDL_PARAM_INOUT:
		ret = get_c_typename () + " " + c_id;
		break;
	case IDL_PARAM_OUT:
		ret = get_c_typename () + "* " + c_id;
		break;
	}
	
	return ret;
}

void
IDLAny::skel_impl_arg_pre (ostream          &ostr,
			   Indent           &indent,
			   const string     &c_id,
			   IDL_param_attr    direction,
			   const IDLTypedef *active_typedef) const
{
	string cpp_id = "_cpp_" + c_id;
	string cpp_type = get_cpp_typename ();
	
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:   
		ostr << indent << cpp_type << " " << cpp_id << " = "
		     << "::CORBA::Any::_orbitcpp_wrap (" << c_id << ");"
		     << endl;
		break;
	case IDL_PARAM_OUT:
		ostr << indent << cpp_type << "_var " << cpp_id << ";" << endl;
		break;
	}    
}

string
IDLAny::skel_impl_arg_call (const string     &c_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	switch (direction)
	{
	case IDL_PARAM_IN:
	case IDL_PARAM_INOUT:
	case IDL_PARAM_OUT:
		return "_cpp_" + c_id;
		break;
		//case IDL_PARAM_OUT:
		//  return get_cpp_typename () + "_out(_cpp_" + c_id + ")";
		//  break;
	}    
}

void
IDLAny::skel_impl_arg_post (ostream          &ostr,
			    Indent           &indent,
			    const string     &c_id,
			    IDL_param_attr    direction,
			    const IDLTypedef *active_typedef) const
{
	string cpp_id = "_cpp_" + c_id;
	
	switch (direction)
	{
	case IDL_PARAM_IN:
		// Do nothing
		break;
	case IDL_PARAM_INOUT:
		ostr << indent << "CORBA_any__copy( " << c_id << ", " << cpp_id
		     << "._orbitcpp_cobj() );" << endl;
		break;
	case IDL_PARAM_OUT:
		ostr << indent << "*" << c_id << " = CORBA_any__alloc();\n";
		ostr << indent << "CORBA_any__copy( *" << c_id << ", " << cpp_id
		     << "->_orbitcpp_cobj() );" << endl;
		break;
	}
}




string
IDLAny::skel_decl_ret_get (const IDLTypedef *active_typedef) const
{
	return get_c_typename ();
}

void
IDLAny::skel_impl_ret_pre (ostream          &ostr,
			   Indent           &indent,
			   const IDLTypedef *active_typedef) const
{
	ostr << indent << get_cpp_typename () << "* _cpp_ret = 0;"
	     << endl;
}

void
IDLAny::skel_impl_ret_call (ostream          &ostr,
			    Indent           &indent,
			    const string     &cpp_call_expression,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << "_cpp_ret = " << cpp_call_expression << ";"
	     << endl;
}

void
IDLAny::skel_impl_ret_post (ostream          &ostr,
			    Indent           &indent,
			    const IDLTypedef *active_typedef) const
{
	ostr << indent << get_c_typename () << " c_ret = CORBA_any__alloc();" << endl;
	ostr << indent << "CORBA_any__copy (c_ret, _cpp_ret->_orbitcpp_cobj ());" << endl;
	ostr << indent << "delete _cpp_ret;" << endl;
	ostr << indent << "return c_ret;" << endl;
}


string
IDLAny::get_cpp_member_typename (const IDLTypedef *active_typedef) const
{
	return "CORBA::Any";
}

string
IDLAny::get_c_member_typename (const IDLTypedef *active_typedef) const
{
	return "CORBA_any";
}

string
IDLAny::get_seq_typename (unsigned int      length,
			  const IDLTypedef *active_typedef) const
{
	string retval;
	string cpp_type = active_typedef ?
		active_typedef->get_cpp_typename () : get_cpp_typename ();
	
	char *tmp = 0;
	if (length)
		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundBoundedSeq< %s, %d>",
				       cpp_type.c_str (), length);
	else
		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundUnboundedSeq< %s >",
				       cpp_type.c_str ());
	
	retval = tmp;
	g_free (tmp);
	
	return retval;
}

string
IDLAny::member_decl_arg_get (const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
	
	cerr << "Any::member_decl_arg_get" << endl;
	
	return "const CORBA::Any&";
}

void
IDLAny::member_impl_arg_copy (ostream          &ostr,
			      Indent           &indent,
			      const string     &cpp_id,
			      const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
	cerr << "Any::member_impl_arg_copy" << endl;
}

void
IDLAny::member_init_cpp (ostream          &ostr,
			 Indent           &indent,
			 const string     &cpp_id,
			 const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}

void
IDLAny::member_init_c (ostream          &ostr,
		       Indent           &indent,
		       const string     &c_id,
		       const IDLTypedef *active_typedef) const
{
#warning "WRITE ME"
}

void
IDLAny::member_pack_to_c (ostream          &ostr,
			  Indent           &indent,
			  const string     &cpp_id,
			  const string     &c_id,
			  const IDLTypedef *active_typedef) const
{
#if 0
	ostr << indent << "CORBA_any__copy (" << c_id
	     << ", " << cpp_id << "._orbitcpp_cobj ());" << endl;
#endif
}

void
IDLAny::member_unpack_from_c  (ostream          &ostr,
			       Indent           &indent,
			       const string     &cpp_id,
			       const string     &c_id,
			       const IDLTypedef *active_typedef) const
{
#if 0
	ostr << indent << cpp_id << ".copy ("
	     << "CORBA::Any::_orbitcpp_wrap (" << c_id << "));" << endl;
#endif
}
